<?php
/*
Plugin Name: FeedCache
Plugin URI: http://www.craigjolicoeur.com/feedcache
Description: Caches RSS Feeds for display on WP site sidebar.  This prevents multiple HTTP requests with each page load since the feeds can be read from the cache file.
Author: Craig P Jolicoeur
Version: 0.4
Author URI: http://www.craigjolicoeur.com/
*/


// Retrieve settings
$rss_list = array();
$rss_list = explode("\n", get_option("feedcache_rss_list"));
$rss_display_num = 5;
$rss_title_pre = "<h3>";
$rss_title_post = "</h3>";
$rss_format_text = 'true';

add_action('admin_menu', 'feedcache');

function fc_find_config_path($fname = 'feedcache-config') {
  $fname = trim($fname);
  $fpath = ABSPATH . "wp-content/plugins/feedcache/" . $fname . '.txt';
  return $fpath;
}
function fc_find_cache_path($fname = 'feedcache-cache') {
  $fname = trim($fname);
  $fpath = ABSPATH . "wp-content/plugins/feedcache/" . $fname . '.txt';
  return $fpath;
}

function fc_read_config_file($fname = 'feedcache-config') {
  $fname = trim($fname);
  if (strlen($fname) > 0) {
    $fname = ABSPATH . "wp-content/plugins/feedcache/" . $fname . '.txt';
    if (file_exists($fname)) {
      $file_content = file($fname);
      return $file_content;
    }
  }
}

function feedcache_display_feeds($fname = 'feedcache-cache') {
  $fname = trim($fname);
  if (strlen($fname) > 0) {
    $fname = ABSPATH . "wp-content/plugins/feedcache/" . $fname . '.txt';
    if (file_exists($fname)) {
      $file_content = file_get_contents($fname);
      return $file_content;
    }
  }
}

function fc_build_config_file($rss_list, $display_num, $title_pre, $title_post, $format_text, $fname = 'feedcache-config') {
  $fname = trim($fname);
  $fpath = ABSPATH . "wp-content/plugins/feedcache/" . $fname . '.txt';

  if (is_writable($fpath)) {
    if (!$handle = fopen($fpath, "w")) {
      echo "Cannot open file ($fpath)";
      exit;
    }

    if (fwrite($handle, "$display_num~$title_pre~$title_post~$format_text\n") === FALSE) {
      echo "Cannot write to file ($fpath)";
      exit;
    }
    if (fwrite($handle, "$rss_list\n") === FALSE) {
      echo "Cannot write to file ($fpath)";
      exit;
    }

    fclose($handle);
  } else {
    echo "The file $fpath is not writable";
  }
}

function feedcache() {
    global $wpdb;
    if (function_exists('add_submenu_page'))
        add_submenu_page('plugins.php', __('FeedCache Options'), __('FeedCache Options'), 1, __FILE__, 'feedcache_subpanel');
}

function feedcache_subpanel() {
    add_option('feedcache_rss_list', '');
    add_option('feedcache_display_num', '5');
    add_option('feedcache_title_pre', "<h3>");
    add_option('feedcache_title_post', "</h3>");
    add_option('feedcache_format_text', 'true');
    
    if ($_POST['stage'] == 'process' ) {
      $fc_rss_list = trim($_POST['feedcache_rss_list']);
      $fc_display_num = $_POST['feedcache_display_num'];
      $fc_title_pre = $_POST['feedcache_title_pre'];
      $fc_title_post = $_POST['feedcache_title_post'];
      $fc_format_text = $_POST['feedcache_format_text'];
      update_option('feedcache_rss_list', $fc_rss_list);
      update_option('feedcache_display_num', $fc_display_num);
      update_option('feedcache_title_pre', $fc_title_pre);
      update_option('feedcache_title_post', $fc_title_post);
      update_option('feedcache_format_text', $fc_format_text);
      fc_build_config_file($fc_rss_list, $fc_display_num, $fc_title_pre, $fc_title_post, $fc_format_text);
    }
    ?>
    
    <div class="wrap">
        <h2 id="write-post">FeedCache&hellip;</h2>
        <p>Fill in the list of RSS feeds you want to process and how you want them formatted and displayed on your site.  If you notice any bugs or have suggestions please contact the developers at <a href="http://www.craigjolicoeur.com/feedcache" title="Craig Jolicoeurs's Home Page">FeedCache on craigjolicoeur.com</a>.</a></p>
        <form method="post" action="<?php echo $_SERVER['PHP_SELF']; ?>?page=feedcache/feedcache.php">
            <input type="hidden" name="stage" value="process" />
            <fieldset class="options">
                <legend>FeedCache Options</legend>
                <div>
		  <label for='feedcache_rss_list'>RSS Feeds [1 per line]</label><br />
		  <p>Following the RSS URL, there are up to three (3) additional options you can specify for each feed: 1. Feed title, 2.
		  Number of items to display, 3. Option to disable special formatting of feed text (boolean value - true/false)</p>
		  <p>If you wish to specify the third option, you MUST also set the first two options.  If you wish to set the
		  second option, you MUST also specify the first option</p>
		  <p>All options should be separated by the pipe ('|') character with no spaces before and after the pipe</p>
          <p>(e.g. http://www.yourfeed.com/feed|Feed Title|4|false)</p>
		  <textarea name="feedcache_rss_list" rows="10" style="width:90%;">
		    <?php echo get_option("feedcache_rss_list"); ?>
		  </textarea>
		</div>
		<div>
		  <p>
		    <label for='feedcache_display_num'>Number of articles to display</label>
		    <input type="text" name="feedcache_display_num" style="width: 20px;" value=<?php echo '\'' . get_option('feedcache_display_num') . '\''; ?> />
		  </p>
			<p>
			  <label for='feedcache_format_text'>Format feed text for proper capitalization</label>
			  <select name="feedcache_format_text">
			    <option value='true' <?php if (get_option('feedcache_format_text') == 'true') { echo 'selected'; } ?> >True</option>
			    <option value='false' <?php if (get_option('feedcache_format_text') == 'false') { echo 'selected'; } ?> >False</option>
			  </select>
		  </p>
		  <p>
		    <label for="feedcache_title_pre_post">Feed Title Display Pre/Post Tags</label>
                    <input type="text" name="feedcache_title_pre" style="width:50px;" value=<?php echo '\''. get_option('feedcache_title_pre') . '\''; ?> />&nbsp;/&nbsp;
                    <input type="text" name="feedcache_title_post" style="width:50px;" value=<?php echo '\''. get_option('feedcache_title_post') . '\''; ?> /> <em style="font-size:11px;">e.g &lt;h2&gt; / &lt;/h2&gt;</em>
		  </p>
		</div>
	    </fieldset>
	    <fieldset id="script-settings" class="options">
	        <legend>CRON Script Settings</legend>
		<p> 
		    Here is the <b>config</b> file path to use in the CRON script:<br />
		    <?php echo fc_find_config_path(); ?>
		</p>
		<p> 
		    Here is the <b>cache</b> file path to use in the CRON script:<br />
		    <?php echo fc_find_cache_path(); ?>
		</p>
            </fieldset>
            <p class="submit"><input type="submit" value="Update FeedCache Preferences &raquo;" name="Submit" /></p>
        </form>
    </div>

<?php            
}
?>
